import { http } from "@/utils/http";

export interface Ab98UserDTO {
  /** 主键ID */
  ab98UserId?: number;
  /** openid */
  openid?: string;
  /** 汇邦云用户唯一ID */
  userid?: string;
  /** 真实姓名 */
  name?: string;
  /** 手机号码 */
  tel?: string;
  /** 身份证号码 */
  idnum?: string;
  /** 性别（男 女） */
  sex?: string;
  /** 人脸照片地址 */
  faceImg?: string;
  /** 身份证正面地址 */
  idcardFront?: string;
  /** 身份证背面地址 */
  idcardBack?: string;
  /** 身份证登记地址 */
  address?: string;
  /** 是否已注册（0未注册 1已注册） */
  registered?: boolean;
}
export interface Ab98UserDetailDTO {
  /** 主键ID */
  ab98UserId?: number;
  /** openid */
  openid?: string;
  /** 汇邦云用户唯一ID */
  userid?: string;
  /** 真实姓名 */
  name?: string;
  /** 手机号码 */
  tel?: string;
  /** 身份证号码 */
  idnum?: string;
  /** 性别（男 女） */
  sex?: string;
  /** 人脸照片地址 */
  faceImg?: string;
  /** 身份证正面地址 */
  idcardFront?: string;
  /** 身份证背面地址 */
  idcardBack?: string;
  /** 身份证登记地址 */
  address?: string;
  /** 是否已注册（0未注册 1已注册） */
  registered?: boolean;
  createTime?: string;
}

export interface Ab98UserQuery extends BasePageQuery {
  /** 真实姓名 */
  name?: string;
  /** 手机号码 */
  tel?: string;
  /** 身份证号码 */
  idnum?: string;
  tagName?: string;
}

export interface AddAb98UserCommand {
  /** openid */
  openid?: string;
  /** 汇邦云用户唯一ID */
  userid?: string;
  /** 真实姓名 */
  name?: string;
  /** 手机号码 */
  tel?: string;
  /** 身份证号码 */
  idnum?: string;
  /** 性别（男 女） */
  sex?: string;
}

export interface UpdateAb98UserCommand extends AddAb98UserCommand {
  /** 主键ID */
  ab98UserId: number;
}

export const getAb98UserListApi = (params: Ab98UserQuery) => {
  return http.request<ResponseData<PageDTO<Ab98UserDTO>>>("get", "/ab98/users", { params });
};

export const addAb98UserApi = (data: AddAb98UserCommand) => {
  return http.request<ResponseData<void>>("post", "/ab98/users", { data });
};

export const updateAb98UserApi = (id: number, data: UpdateAb98UserCommand) => {
  return http.request<ResponseData<void>>("put", `/ab98/users/${id}`, { data });
};

export const deleteAb98UserApi = (ids: number[]) => {
  return http.request<ResponseData<void>>("delete", `/ab98/users/${ids.join(',')}`);
};

export const getAb98UserDetailApi = (id: number) => {
  return http.request<ResponseData<Ab98UserDetailDTO>>("get", `/ab98/users/detail/${id}`);
};